==> form-dinamico-react-render-0.1.2.tgz: package/es/widgets/mui/DatePickerWidget.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import KeyboardArrowLeft from '@material-ui/icons/KeyboardArrowLeft';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';

import { DatePicker } from 'material-ui-pickers';

import IconButton from 'material-ui/IconButton';
import { InputAdornment } from 'material-ui/Input';
import Close from '@material-ui/icons/Close';

import 'moment/locale/pt-br';

// TODO: https://github.com/dmtrKovalenko/material-ui-pickers/issues/125
// TODO: Quando a data estiver nula, vai aparecer a data atual, aguardar issue do componente
function DatePickerWidget(props) {
    var value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        schema = props.schema,
        formContext = props.formContext,
        registry = props.registry,
        type = props.type,
        inputProps = _objectWithoutProperties(props, ['value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'schema', 'formContext', 'registry', 'type']);

    var onChange = function onChange(value) {
        var formatted = value ? value.toISOString() : options.emptyValue;

        return props.onChange(formatted);
    };

    var handleClearClick = function handleClearClick(event) {
        event.stopPropagation();
        return props.onChange('');
    };

    var textFieldProps = value ? {
        endAdornment: React.createElement(
            InputAdornment,
            { position: 'end' },
            React.createElement(
                IconButton,
                { onClick: handleClearClick },
                React.createElement(Close, null)
            )
        )
    } : {};

    return React.createElement(DatePicker, _extends({}, inputProps, {
        value: value,
        invalidLabel: '',
        format: 'L',
        onChange: onChange,
        onBlur: onBlur && function (event) {
            return onBlur(inputProps.id, event.target.value);
        },
        onFocus: onFocus && function (event) {
            return onFocus(inputProps.id, event.target.value);
        },
        leftArrowIcon: React.createElement(KeyboardArrowLeft, null),
        rightArrowIcon: React.createElement(KeyboardArrowRight, null),
        readOnly: readonly,
        disabled: disabled || readonly,
        cancelLabel: 'Cancelar',
        InputProps: textFieldProps
    }));
}

DatePickerWidget.defaultProps = {
    type: 'date',
    required: false,
    disabled: false,
    readonly: false,
    autofocus: false
};

DatePickerWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    id: PropTypes.string.isRequired,
    placeholder: PropTypes.string,
    value: PropTypes.any,
    required: PropTypes.bool,
    disabled: PropTypes.bool,
    readonly: PropTypes.bool,
    autofocus: PropTypes.bool,
    onChange: PropTypes.func,
    onBlur: PropTypes.func,
    onFocus: PropTypes.func
} : {};

export default DatePickerWidget;

==> form-dinamico-react-render-0.1.7.tgz: package/es/widgets/mui/DatePickerWidget.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import KeyboardArrowLeft from '@material-ui/icons/KeyboardArrowLeft';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';

import { DatePicker } from 'material-ui-pickers';

import IconButton from 'material-ui/IconButton';
import { InputAdornment } from 'material-ui/Input';
import Close from '@material-ui/icons/Close';

import 'moment/locale/pt-br';

// TODO: https://github.com/dmtrKovalenko/material-ui-pickers/issues/125
// TODO: Quando a data estiver nula, vai aparecer a data atual, aguardar issue do componente
function DatePickerWidget(props) {
    var value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        schema = props.schema,
        formContext = props.formContext,
        registry = props.registry,
        type = props.type,
        inputProps = _objectWithoutProperties(props, ['value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'schema', 'formContext', 'registry', 'type']);

    var onChange = function onChange(value) {
        var formatted = value ? value.toISOString() : options.emptyValue;

        return props.onChange(formatted);
    };

    var handleClearClick = function handleClearClick(event) {
        event.stopPropagation();
        return props.onChange('');
    };

    var textFieldProps = value ? {
        endAdornment: React.createElement(
            InputAdornment,
            { position: 'end' },
            React.createElement(
                IconButton,
                { onClick: handleClearClick },
                React.createElement(Close, null)
            )
        )
    } : {};

    return React.createElement(DatePicker, _extends({}, inputProps, {
        value: value,
        invalidLabel: '',
        format: 'L',
        onChange: onChange,
        onBlur: onBlur && function (event) {
            return onBlur(inputProps.id, event.target.value);
        },
        onFocus: onFocus && function (event) {
            return onFocus(inputProps.id, event.target.value);
        },
        leftArrowIcon: React.createElement(KeyboardArrowLeft, null),
        rightArrowIcon: React.createElement(KeyboardArrowRight, null),
        readOnly: readonly,
        disabled: schema.disabled || readonly,
        cancelLabel: 'Cancelar',
        InputProps: textFieldProps
    }));
}

DatePickerWidget.defaultProps = {
    type: 'date',
    required: false,
    disabled: false,
    readonly: false,
    autofocus: false
};

DatePickerWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    id: PropTypes.string.isRequired,
    placeholder: PropTypes.string,
    value: PropTypes.any,
    required: PropTypes.bool,
    disabled: PropTypes.bool,
    readonly: PropTypes.bool,
    autofocus: PropTypes.bool,
    onChange: PropTypes.func,
    onBlur: PropTypes.func,
    onFocus: PropTypes.func
} : {};

export default DatePickerWidget;
